<section style="height: 30vw; min-height: 15rem;
      background: linear-gradient(#268762, #15ac7f)">
        <div style="
          height: 30vw;
          min-height: 15rem;
          background-image: url(https://raw.githubusercontent.com/repronim/nimh-minimal/main/nimh_minimal/about_the_study.svg);
          background-position: center;
          background-size: contain;
          background-repeat: no-repeat">
        </div>
      </section>
      <br>
<section>

# Welcome to NIMH Required Data Elements Collection

Minimal list of data collection instruments that would be ideal for use by all mental
health researchers conducting clinical research to facilitate and harmonize mental health
data collection.
